//	CassidySettingsView.cc

#include "CassidySettingsView.h"
#include "Cassidy.h"

enum
{
	CC_SET_REDRAW = 'ccSR',
	CC_SET_COLOR = 'ccSC',
	CC_CYCLE_COLOR = 'ccCC'
};

CassidySettingsView::CassidySettingsView(BRect frame, BlanketModule *o, int refresh, bool inColor, int cycle)
	: BView(frame,NULL,B_FOLLOW_ALL_SIDES,B_WILL_DRAW)
{
	BFont font;
	BRect rect;
	BStringView *label;
	font_height fontHeight;
	
	owner = o;
	font.SetSize(14);
	font.GetHeight(&fontHeight);
	rect = Bounds();
	rect.bottom = rect.top+fontHeight.ascent+fontHeight.descent+fontHeight.leading;
	label = new BStringView(rect,NULL,"Cassidy");
	label->SetFont(&font);
	label->SetAlignment(B_ALIGN_CENTER);
	AddChild(label);
	rect.top = rect.bottom+1;
	font.SetSize(9);
	font.GetHeight(&fontHeight);
	rect.bottom = rect.top+fontHeight.ascent+fontHeight.descent+fontHeight.leading;
	label = new BStringView(rect,NULL,"version 1.0");
	label->SetFont(&font);
	label->SetAlignment(B_ALIGN_CENTER);
	AddChild(label);
	rect.top = rect.bottom+1;
	font.SetSize(10);
	font.GetHeight(&fontHeight);
	rect.bottom = rect.top+fontHeight.ascent+fontHeight.descent+fontHeight.leading;
	label = new BStringView(rect,NULL,"by Ernest Tomlinson");
	label->SetFont(&font);
	label->SetAlignment(B_ALIGN_CENTER);
	AddChild(label);
	rect.top = rect.bottom+2;
	rect.bottom = rect.top;
	redrawSlider = new BSlider(rect,NULL,"Draw a new pattern...",new BMessage(CC_SET_REDRAW),3,150);
	redrawSlider->SetValue(refresh);
	redrawSlider->SetHashMarkCount(8);
	redrawSlider->SetHashMarks(B_HASH_MARKS_BOTTOM);
	redrawSlider->SetLimitLabels("Often","Seldom");
	redrawSlider->ResizeToPreferred();
	AddChild(redrawSlider);
	rect.top = rect.bottom+redrawSlider->Bounds().Height()+2;
	rect.bottom = rect.top;
	colorCheck = new BCheckBox(rect,NULL,"Draw in Color",new BMessage(CC_SET_COLOR));
	colorCheck->SetValue(inColor ? B_CONTROL_ON : B_CONTROL_OFF);
	colorCheck->ResizeToPreferred();
	AddChild(colorCheck);
	rect.top = rect.bottom+colorCheck->Bounds().Height()+2;
	rect.bottom = rect.top;
	rect.left += 10;
	rect.right -= 10;
	colorSlider = new BSlider(rect,NULL,"Cycle through colors...",new BMessage(CC_CYCLE_COLOR),360,48000);
	colorSlider->SetValue(cycle);
	colorSlider->SetHashMarkCount(8);
	colorSlider->SetHashMarks(B_HASH_MARKS_BOTTOM);
	colorSlider->SetLimitLabels("Quickly","Glacially");
	colorSlider->ResizeToPreferred();
	AddChild(colorSlider);
	colorSlider->SetEnabled(inColor);
}

void CassidySettingsView::AttachedToWindow(void)
{
	SetViewColor(Parent()->ViewColor());
	redrawSlider->SetTarget(this);
	colorCheck->SetTarget(this);
	colorSlider->SetTarget(this);
}

void CassidySettingsView::MessageReceived(BMessage *message)
{
	Cassidy *obj = (Cassidy *)owner;
	
	switch (message->what)
	{
		case CC_SET_REDRAW:
			obj->refresh = redrawSlider->Value();
			break;
		case CC_SET_COLOR:
			if (colorCheck->Value() == B_CONTROL_ON)
			{
				obj->inColor = true;
				colorSlider->SetEnabled(true);
			}
			else
			{
				obj->inColor = false;
				colorSlider->SetEnabled(false);
			}
			break;
		case CC_CYCLE_COLOR:
			obj->cycle = colorSlider->Value();
			break;
		default:
			BView::MessageReceived(message);
			break;
	}
}
